// Craig S. Kaplan
// A complicated teaching demo for visualizing points with
// Cartesian coordinates.  Once again, this is more useful as
// an in-class demo.  We'll run it, but not study its source
// code.  In theory there's nothing here that can't be understood
// with CS 105 / 106 concepts, but it's a bit complex.

import processing.pdf.*;

boolean recording;

void setup()
{
  size( 510, 510 );
  textSize( 16 );
  noCursor();
}

void draw()
{
  if( recording ) {
    beginRecord( PDF, "output.pdf" );
  }
  
  background( 255 );

  stroke( 0 );
  strokeWeight( 0.5 );
  for ( int idx = 5; idx < 510; idx += 50 ) {
    line( 0, idx, width, idx );
    line( idx, 0, idx, height );
  }

  strokeWeight( 3 );
  line( 0, height/2, width, height/2 );
  line( width/2, 0, width/2, height );

  fill( 255 );
  noStroke();
  rect( 0, 0, 220, 25 );

  textSize( 20 );
  textAlign( LEFT );
  fill( 0 );
  text( "Cartesian coordinates", 5, 20 );

  String x_str = nf( 0.02*(mouseX - width/2), 0, 1 );
  String y_str = nf( 0.02*(height/2 - mouseY), 0, 1 );
  
  strokeWeight( 4 );
  stroke( 255, 0, 0 );
  line( width/2, mouseY - 18, mouseX, mouseY - 18 );
  line( width/2, mouseY - 8, width/2, mouseY - 28 );
  line( mouseX, mouseY - 8, mouseX, mouseY - 28 );
  fill( 255, 0, 0 );
  textAlign( CENTER );
  text( x_str, 0.5*(mouseX+width/2), mouseY - 23 );

  stroke( 0, 0, 255 );
  line( mouseX + 18, mouseY, mouseX + 18, height/2 );
  line( mouseX, mouseY, mouseX + 28, mouseY );
  line( mouseX, height/2, mouseX + 28, height/2 );
  fill( 0, 0, 255 );
  textAlign( LEFT );
  text( y_str, mouseX + 23, 0.5*(mouseY+height/2) );

  noStroke();
  fill( 255 );
  rect( width-100, height-55, 100, 55 );

  textAlign( RIGHT );
  fill( 255, 0, 0 );
  text( "x = " + x_str, width-10, height-30 );
  fill( 0, 0, 255 );
  text( "y = " + y_str, width-10, height-8 );

  noStroke();
  fill( 0 );
  ellipse( mouseX, mouseY, 15, 15 );
  noStroke();
  fill( 0 );
  ellipse( mouseX, mouseY, 15, 15 );
  
  if( recording ) {
    endRecord();
    recording = false;
  }
}

void keyPressed()
{
  if( key == ' ' ) {
    recording = true;
  }
}