// Craig S. Kaplan
// A visualization of a family of graphs, showing
// the month-to-month sea ice levels over a number
// of years.  The data are taken from NSIDC, the
// National Snow and Ice Data Centre.

// This sketch has been updated for 2018 with what I think is
// the most recent data, from here:
// ftp://sidads.colorado.edu/DATASETS/NOAA/G02135/north/monthly/
// (via https://nsidc.org/data/seaice_index/)
// But I'm a bit uncomfortable about it, because the historical
// data seems to have changed slightly.  I'm not sure if I'm looking
// at a different archive, or if they go back and revise historical
// data based on new methods of estimation.

String[] lines;
int cur;

void setup()
{
  size( 800, 400 );
  lines = loadStrings( "monthly.txt" );
  cur = 0;
  textSize( 20 );
}

void draw()
{  
  background( 80 );

  colorMode( HSB, 255 );
  noFill();
  strokeWeight( 1 );

  for ( int idx = 0; idx < cur; ++idx ) {
    stroke( map( idx, 0, lines.length - 1, 0, 255 ), 255, 255 );
    drawGraph( lines[idx] );
  }

  if ( cur > 0 ) {
    noStroke();
    fill( map( cur-1, 0, lines.length - 1, 0, 255 ), 255, 255 );
    rect( 10, height - 30, 20, 20 );
    text( splitTokens(lines[cur-1])[0], 35, height - 12 );
  }
}

void drawGraph( String line )
{
  float[] vals = subset( float( splitTokens( line ) ), 1, 12 );
  // println( min( vals ), max( vals ) );
  beginShape();
  for ( int idx = 0; idx < vals.length; ++idx ) {
    float x = map( idx, 0, vals.length-1, 0, width );
    float y = map( vals[idx], 3, 17, height, 0 );
    vertex( x, y );
  }
  endShape();
}

void keyPressed()
{
  if ( keyCode == LEFT ) {
    cur = max( cur - 1, 0 );
  } else if ( keyCode == RIGHT ) {
    cur = min( cur + 1, lines.length );
  }
}